==> Xarm-1.2.7.tar.gz: Xarm-1.2.7/include/Xarm/CascadeB.h <==
/* $Id: CascadeB.h,v 1.2 1997/04/07 15:33:17 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_CASCADEB_H_)
#define _XARM_CASCADEB_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Label.h>

class CascadeButtonClass : public LabelClass {
 protected:
   CascadeButtonClass() {} /* only a derived class can make this */

   virtual WidgetClass classPointer() { return xmCascadeButtonWidgetClass; }
   virtual _XtString className() { return (_XtString) "XmCascadeButton"; }
 public:
   /* Callbacks */
   void activateCallback(XtCallbackProc funcp, XtPointer data = NULL);
   void cascadingCallback(XtCallbackProc funcp, XtPointer data = NULL);

   /* resources */
   void cascadePixmap(Pixmap);
   Pixmap cascadePixmap();
   void mappingDelay(int);
   int mappingDelay();
   void subMenuId(Widget sub); /* expects a PulldownMenu */
   Widget subMenuId();
};

class CascadeButton : public CascadeButtonClass {
 public:
   CascadeButton(Widget w_parent, char *str, _XtString name = NULL);
   CascadeButton(Widget w_parent, 
                 ArgList arglist = NULL, 
                 Cardinal cnt = 0, 
                 _XtString name = NULL);
   CascadeButton(_XtString name, Widget w_parent);
   CascadeButton(Widget w_parent, XarmArg &args, _XtString name);
};

#endif

==> Xarm-1.3.1.tar.gz: Xarm-1.3.1/include/Xarm/CascadeB.h <==
/* $Id: CascadeB.h,v 1.3 1999/01/15 01:07:23 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_CASCADEB_H_)
#define _XARM_CASCADEB_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Label.h>

class CascadeButtonClass : public LabelClass {
 protected:
   CascadeButtonClass() {} /* only a derived class can make this */

   virtual WidgetClass classPointer() { return xmCascadeButtonWidgetClass; }
   virtual _XtString className() { return (_XtString) "XmCascadeButton"; }
 public:
   /* Callbacks */
   void activateCallback(XtCallbackProc funcp, XtPointer data = NULL);
   void cascadingCallback(XtCallbackProc funcp, XtPointer data = NULL);

   /* resources */
   void cascadePixmap(Pixmap);
   Pixmap cascadePixmap() const;
   void mappingDelay(int);
   int mappingDelay() const;
   void subMenuId(Widget sub); /* expects a PulldownMenu */
   Widget subMenuId() const;
};

class CascadeButton : public CascadeButtonClass {
 public:
   CascadeButton(Widget w_parent, const char *str, _XtString name = NULL);
   CascadeButton(Widget w_parent, 
                 ArgList arglist = NULL, 
                 Cardinal cnt = 0, 
                 _XtString name = NULL);
   CascadeButton(_XtString name, Widget w_parent);
   CascadeButton(Widget w_parent, XarmArg &args, _XtString name);
};

#endif
